==> node-webpack_3.5.6.orig.tar.gz: webpack-3.5.6/test/configCases/target/node-dynamic-import/index.js <==
function testCase(load, done) {
	load("two", 2, function() {
		var sync = true;
		load("one", 1, function() {
			sync.should.be.eql(false);
			load("three", 3, function() {
				var sync = true;
				load("two", 2, function() {
					sync.should.be.eql(true);
					done();
				});
				Promise.resolve().then(function() {}).then(function() {}).then(function() {
					sync = false;
				});
			});
		});
		Promise.resolve().then(function() {
			sync = false;
		});
	});
}

it("should be able to use expressions in import", function(done) {
	function load(name, expected, callback) {
		import("./dir/" + name + '.js')
			.then((result) => {result.should.be.eql(expected); callback()})
			.catch((err) => {done(err)});
	}
	testCase(load, done);
});

it("should be able to use expressions in System.import", function(done) {
	function load(name, expected, callback) {
		System.import("./dir2/" + name).then((result) => {
			result.should.be.eql(expected);
			callback();
		}).catch((err) => {
			done(err);
		});
	}
	testCase(load, done);
});

it("should convert to function in node", function() {
	(typeof __webpack_require__.e).should.be.eql("function");
})

it("should be able to use import", function(done) {
	import("./two").then((two) => {
		two.should.be.eql(2);
		done();
	}).catch(function(err) {
		done(err);
	});
});

it("should be able to use System.import", function(done) {
	System.import("./two").then((two) => {
		two.should.be.eql(2);
		done();
	}).catch(function(err) {
		done(err);
	});
});

==> node-webpack_4.7.0.orig.tar.gz: webpack-4.7.0/test/configCases/target/node-dynamic-import/index.js <==
function testCase(load, done) {
	load("two", 2, function() {
		var sync = true;
		load("one", 1, function() {
			expect(sync).toBe(false);
			load("three", 3, function() {
				var sync = true;
				load("two", 2, function() {
					expect(sync).toBe(true);
					done();
				});
				Promise.resolve().then(function() {}).then(function() {}).then(function() {
					sync = false;
				});
			});
		});
		Promise.resolve().then(function() {
			sync = false;
		});
	});
}

it("should be able to use expressions in import", function(done) {
	function load(name, expected, callback) {
		import("./dir/" + name + '.js')
			.then((result) => {expect(result).toEqual({ default: expected }); callback()})
			.catch((err) => {done(err)});
	}
	testCase(load, done);
});

it("should be able to use expressions in lazy-once import", function(done) {
	function load(name, expected, callback) {
		import(/* webpackMode: "lazy-once" */ "./dir/" + name + '.js')
			.then((result) => {expect(result).toEqual({ default: expected }); callback()})
			.catch((err) => {done(err)});
	}
	testCase(load, done);
});

it("should be able to use expressions in import", function(done) {
	function load(name, expected, callback) {
		import("./dir2/" + name).then((result) => {
			expect(result).toEqual({ default: expected });
			callback();
		}).catch((err) => {
			done(err);
		});
	}
	testCase(load, done);
});

it("should convert to function in node", function() {
	expect((typeof __webpack_require__.e)).toBe("function");
})

it("should be able to use import", function(done) {
	import("./two").then((two) => {
		expect(two).toEqual({ default: 2 });
		done();
	}).catch(function(err) {
		done(err);
	});
});
